Welcome to texsite
==================

.. image:: https://img.shields.io/travis/texperience/texsite.svg?branch=master
    :target: https://travis-ci.org/texperience/texsite

.. image:: https://img.shields.io/coveralls/texperience/texsite/master.svg
    :target: https://coveralls.io/r/texperience/texsite?branch=master

.. image:: https://img.shields.io/pypi/v/texsite.svg
    :target: https://pypi.python.org/pypi/texsite

.. image:: https://img.shields.io/pypi/l/texsite.svg
    :target: http://en.wikipedia.org/wiki/ISC_license

texsite delivers great and ready-to-use page templates for the modern, flexible and user-focused web content management system `Wagtail CMS`_ backed by the popular `Django web framework`_, both written in `Python`_.

Based on the amazing `StreamField`_ introduced with Wagtail release 1.0, which texsite uses extensively, it has never been easier for editors to author awesome pages. Read more on how this concept works in the great blog article `Rich text fields and faster horses`_ written by Matt Westcott, lead technical developer of Wagtail.

.. _Wagtail CMS: https://wagtail.io/
.. _Django web framework: https://www.djangoproject.com/
.. _Python: https://www.python.org/
.. _StreamField: http://docs.wagtail.io/en/stable/topics/streamfield.html
.. _Rich text fields and faster horses: https://torchbox.com/blog/rich-text-fields-and-faster-horses/

Feature list
------------

* Clean Blog Pages - based on the `Clean Blog`_ theme by Start Bootstrap
* Business Casual Pages - based on the `Business Casual`_ theme by Start Bootstrap
* Outstanding test coverage
* Continuously integrated codebase

.. _Clean Blog: https://startbootstrap.com/template-overviews/clean-blog/
.. _Business Casual: https://startbootstrap.com/template-overviews/business-casual/

Technical requirements
----------------------

Below is the list of currently supported combinations of Wagtail, Django and Python:

+------------+------------+------------+--------------------+
| #          | Wagtail    | Django     | Python             |
+============+============+============+====================+
| 1          | 1.9        | 1.8        | 2.7, 3.3, 3.4, 3.5 |
+------------+------------+------------+--------------------+
| 2          | 1.9        | 1.9, 1.10  | 2.7, 3.4, 3.5      |
+------------+------------+------------+--------------------+

Code and contribution
---------------------

The code is open source and released under the `ISC License (ISCL)`_. It is available on `GitHub`_ and follows the guidelines about `Semantic Versioning`_ for transparency within the release cycle and backward compatibility whenever possible.

All contributions are welcome, whether bug reports, code contributions and reviews, documentation or feature requests.

.. _ISC License (ISCL): http://en.wikipedia.org/wiki/ISC_license
.. _Semantic Versioning: http://semver.org/
.. _GitHub: https://github.com/texperience/texsite
